





**findUnmutatedCalls** - *Determine which calls represent an unmutated allele*

Description
--------------------

`findUnmutatedCalls` determines which allele calls would represent a 
perfect match with the germline sequence, given a vector of allele calls and
mutation counts. In the case of multiple alleles being assigned to a
sequence, only the subset that would represent a perfect match is returned.


Usage
--------------------
```
findUnmutatedCalls(allele_calls, sample_seqs, germline_db)
```

Arguments
-------------------

allele_calls
:   a vector of strings respresenting Ig allele calls,
where multiple calls are separated by a comma

sample_seqs
:   V(D)J-rearranged sample sequences matching the order
of the given `allele_calls`

germline_db
:   a vector of named nucleotide germline sequences



Value
-------------------

A vector of strings containing the members of `allele_calls`
that represent unmutated sequences



Examples
-------------------

```R
# Load data
data(germline_ighv)
data(sample_db)

# Find which of the sample alleles are unmutated
findUnmutatedCalls(sample_db$V_CALL, sample_db$SEQUENCE_IMGT, germline_ighv)
```


```
   [1] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"   
   [9] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-46*01"  
  [17] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-2*02"   
  [25] "IGHV1-46*01"   "IGHV1-69*02"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"  
  [33] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-3*01"   
  [41] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"  
  [49] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*04"  
  [57] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-18*01"  
  [65] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*04"  
  [73] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"  
  [81] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-8*01"   
  [89] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"  
  [97] "IGHV1-24*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-3*01"   
 [105] "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-58*02"   "IGHV1-3*01"   
 [113] "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*04"  
 [121] "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-3*01"   
 [129] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*01"  
 [137] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69*04"  
 [145] "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*04"  
 [153] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"   
 [161] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"   
 [169] "IGHV1-69*02"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-3*01"   
 [177] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*06"  
 [185] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-3*01"   
 [193] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"  
 [201] "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-8*01"   
 [209] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"  
 [217] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"   
 [225] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69-2*01" "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"   
 [233] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-18*01"  
 [241] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-24*01"  
 [249] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-3*01"   
 [257] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-8*01"   
 [265] "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-8*01"   
 [273] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"  
 [281] "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"   
 [289] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"  
 [297] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-69*01"  
 [305] "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-2*02"   
 [313] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"  
 [321] "IGHV1-24*01"   "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*01"  
 [329] "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*06"  
 [337] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"  
 [345] "IGHV1-69*04"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"  
 [353] "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"  
 [361] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"  
 [369] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-8*01"   
 [377] "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-24*01"  
 [385] "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-3*01"   
 [393] "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-18*01"  
 [401] "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
 [409] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"  
 [417] "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*02"   "IGHV1-18*01"  
 [425] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-8*01"   
 [433] "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-58*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-24*01"  
 [441] "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"   
 [449] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"   
 [457] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"   
 [465] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"  
 [473] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-2*02"   
 [481] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"  
 [489] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"   
 [497] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"  
 [505] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-58*01"  
 [513] "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-8*01"   
 [521] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"  
 [529] "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"   
 [537] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*01"  
 [545] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"   
 [553] "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"  
 [561] "IGHV1-58*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-46*01"  
 [569] "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"   
 [577] "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-46*01"  
 [585] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-2*02"    "IGHV1-69*06"  
 [593] "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"  
 [601] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"  
 [609] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-2*02"   
 [617] "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"  
 [625] "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69-2*01" "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"   
 [633] "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-3*01"   
 [641] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"  
 [649] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-46*01"  
 [657] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"  
 [665] "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"  
 [673] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"   
 [681] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"   
 [689] "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-58*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"  
 [697] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-8*01"   
 [705] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"  
 [713] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-3*01"   
 [721] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-46*01"  
 [729] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*02"   
 [737] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*01"  
 [745] "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"   
 [753] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-69*04"  
 [761] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-24*01"  
 [769] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"  
 [777] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"  
 [785] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"   
 [793] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-58*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"   
 [801] "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*04"   
 [809] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"  
 [817] "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-18*01"  
 [825] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"   
 [833] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"  
 [841] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"   
 [849] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-8*01"   
 [857] "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-8*01"   
 [865] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-58*01"   "IGHV1-46*01"  
 [873] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"   
 [881] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"   
 [889] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*04"  
 [897] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-3*01"   
 [905] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-58*02"   "IGHV1-58*02"  
 [913] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"  
 [921] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"  
 [929] "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"  
 [937] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*04"  
 [945] "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"  
 [953] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"  
 [961] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-2*02"   
 [969] "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*01"  
 [977] "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"  
 [985] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-46*01"  
 [993] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"  
[1001] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-18*01"  
[1009] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"  
[1017] "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[1025] "IGHV1-2*04"    "IGHV1-58*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"  
[1033] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[1041] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69-2*01" "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[1049] "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-58*01"   "IGHV1-2*04"    "IGHV1-69*01"  
[1057] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69-2*01"
[1065] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*04"  
[1073] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-24*01"  
[1081] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"  
[1089] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-46*01"  
[1097] "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"  
[1105] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"   
[1113] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[1121] "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"  
[1129] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-69*04"  
[1137] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"  
[1145] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-8*01"    "IGHV1-46*01"  
[1153] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[1161] "IGHV1-69-2*01" "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*04"  
[1169] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"   
[1177] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69-2*01" "IGHV1-69*01"   "IGHV1-69*01"  
[1185] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"  
[1193] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-69*01"  
[1201] "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"  
[1209] "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*04"   
[1217] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"   
[1225] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"  
[1233] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"  
[1241] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*04"   
[1249] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*04"   
[1257] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"  
[1265] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69-2*01" "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"  
[1273] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-8*01"   
[1281] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*04"   
[1289] "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[1297] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"   
[1305] "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-24*01"  
[1313] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-69*04"  
[1321] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-46*01"  
[1329] "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[1337] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"  
[1345] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-24*01"   "IGHV1-18*01"  
[1353] "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"  
[1361] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*01"  
[1369] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"  
[1377] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[1385] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[1393] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-46*01"  
[1401] "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69*01"  
[1409] "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"  
[1417] "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-46*01"  
[1425] "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-24*01"  
[1433] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*01"  
[1441] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"  
[1449] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"   
[1457] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[1465] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-3*01"   
[1473] "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[1481] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*04"  
[1489] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-46*01"  
[1497] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-46*01"  
[1505] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-58*02"  
[1513] "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[1521] "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-8*01"   
[1529] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-8*01"   
[1537] "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-8*01"   
[1545] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"  
[1553] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"   
[1561] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*04"  
[1569] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[1577] "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-69*02"   "IGHV1-46*01"  
[1585] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-2*02"   
[1593] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"   
[1601] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"   
[1609] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"   
[1617] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-69*06"  
[1625] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-18*01"  
[1633] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"  
[1641] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69-2*01" "IGHV1-69*02"   "IGHV1-69*06"   "IGHV1-69*01"  
[1649] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"  
[1657] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[1665] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-8*01"   
[1673] "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-24*01"  
[1681] "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"   
[1689] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*06"  
[1697] "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-58*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"  
[1705] "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-3*01"   
[1713] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*06"  
[1721] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[1729] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*06"  
[1737] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*04"   
[1745] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-2*02"    "IGHV1-69*01"  
[1753] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-3*01"   
[1761] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-2*02"   
[1769] "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*02"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"  
[1777] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-8*01"   
[1785] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*04"  
[1793] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[1801] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-24*01"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*02"   
[1809] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-46*01"  
[1817] "IGHV1-69*02"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"  
[1825] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-58*01"   "IGHV1-69*06"  
[1833] "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*02"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"   
[1841] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"   
[1849] "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-46*01"  
[1857] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-8*01"   
[1865] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"  
[1873] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"  
[1881] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-58*02"  
[1889] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-24*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"  
[1897] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"   
[1905] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"  
[1913] "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-8*01"   
[1921] "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*02"   
[1929] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-3*01"   
[1937] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-46*01"  
[1945] "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-69*01"  
[1953] "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"  
[1961] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[1969] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"   
[1977] "IGHV1-69-2*01" "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*02"   
[1985] "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"  
[1993] "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-2*04"   
[2001] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"  
[2009] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-2*02"   
[2017] "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-3*01"   
[2025] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"   
[2033] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"  
[2041] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"   
[2049] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-3*01"   
[2057] "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-8*01"   
[2065] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*01"  
[2073] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"  
[2081] "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-18*01"  
[2089] "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-8*01"   
[2097] "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-24*01"  
[2105] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*01"  
[2113] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-8*01"   
[2121] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-3*01"   
[2129] "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"   
[2137] "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"   
[2145] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"   
[2153] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[2161] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*01"  
[2169] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*01"  
[2177] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-69*01"  
[2185] "IGHV1-69*02"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*04"   
[2193] "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[2201] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"  
[2209] "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-69*01"  
[2217] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"   
[2225] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"  
[2233] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-58*01"   "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"  
[2241] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-8*01"   
[2249] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"   
[2257] "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-58*02"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-46*01"  
[2265] "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-46*01"  
[2273] "IGHV1-18*01"   "IGHV1-58*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[2281] "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"  
[2289] "IGHV1-69*06"   "IGHV1-58*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*01"  
[2297] "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[2305] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-46*01"  
[2313] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[2321] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-58*01"  
[2329] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-2*02"   
[2337] "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-69*01"  
[2345] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"  
[2353] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-8*01"   
[2361] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"  
[2369] "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"  
[2377] "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*04"  
[2385] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-69*06"  
[2393] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*01"  
[2401] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*04"   
[2409] "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"  
[2417] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"  
[2425] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-58*02"   "IGHV1-8*01"    "IGHV1-46*01"  
[2433] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*04"   
[2441] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-8*01"   
[2449] "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"  
[2457] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-58*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"  
[2465] "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*04"   
[2473] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*04"  
[2481] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*01"  
[2489] "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"  
[2497] "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"  
[2505] "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-69*01"  
[2513] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-3*01"   
[2521] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-58*02"   "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69-2*01"
[2529] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"  
[2537] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*02"  
[2545] "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-8*01"   
[2553] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*04"   
[2561] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-24*01"  
[2569] "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"  
[2577] "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*06"  
[2585] "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"   
[2593] "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*04"  
[2601] "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"  
[2609] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-3*01"   
[2617] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[2625] "IGHV1-24*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-3*01"   
[2633] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*04"   
[2641] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*01"  
[2649] "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-58*02"   "IGHV1-69*06"  
[2657] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69-2*01"
[2665] "IGHV1-24*01"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[2673] "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"  
[2681] "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-2*02"   
[2689] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*04"  
[2697] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-46*01"  
[2705] "IGHV1-24*01"   "IGHV1-8*01"    "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-46*01"  
[2713] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-24*01"  
[2721] "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69-2*01" "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"  
[2729] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[2737] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*01"  
[2745] "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"  
[2753] "IGHV1-69*01"   "IGHV1-58*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-24*01"  
[2761] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"  
[2769] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69-2*01"
[2777] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[2785] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*01"  
[2793] "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"  
[2801] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-69-2*01" "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"  
[2809] "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*04"  
[2817] "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[2825] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*04"   
[2833] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*02"   
[2841] "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69-2*01" "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*04"  
[2849] "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*04"  
[2857] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"  
[2865] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[2873] "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-69-2*01" "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[2881] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"   
[2889] "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"  
[2897] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"  
[2905] "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"  
[2913] "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"  
[2921] "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*02"   "IGHV1-46*01"   "IGHV1-8*01"   
[2929] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"  
[2937] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-46*01"  
[2945] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*04"  
[2953] "IGHV1-69*06"   "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*02"   "IGHV1-2*04"    "IGHV1-8*01"   
[2961] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*04"  
[2969] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-69*01"  
[2977] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"  
[2985] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"   
[2993] "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[3001] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-2*02"   
[3009] "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-2*02"   
[3017] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*06"  
[3025] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*06"  
[3033] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"   
[3041] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"   
[3049] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-2*04"   
[3057] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-58*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"   
[3065] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-69*01"  
[3073] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69-2*01" "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*04"  
[3081] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"   
[3089] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-3*01"   
[3097] "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"  
[3105] "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-3*01"   
[3113] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*04"   
[3121] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"  
[3129] "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"  
[3137] "IGHV1-69-2*01" "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[3145] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-8*01"   
[3153] "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*04"   
[3161] "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-46*01"  
[3169] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"  
[3177] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*06"  
[3185] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*06"  
[3193] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-8*01"   
[3201] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[3209] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-8*01"   
[3217] "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*04"   
[3225] "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"  
[3233] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*04"  
[3241] "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"  
[3249] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*01"  
[3257] "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*01"  
[3265] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"  
[3273] "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-69-2*01" "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-8*01"   
[3281] "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-46*01"  
[3289] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*04"  
[3297] "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"  
[3305] "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-46*01"  
[3313] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-46*01"  
[3321] "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"  
[3329] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[3337] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-2*04"   
[3345] "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-69*04"  
[3353] "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"   
[3361] "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-46*01"  
[3369] "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-3*01"   
[3377] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69*01"  
[3385] "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*02"   
[3393] "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-3*01"   
[3401] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"  
[3409] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-46*01"  
[3417] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"   
[3425] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-58*02"   "IGHV1-69*01"   "IGHV1-3*01"   
[3433] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-58*02"   "IGHV1-69*01"   "IGHV1-18*01"  
[3441] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[3449] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"  
[3457] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-24*01"  
[3465] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*04"   
[3473] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-3*01"   
[3481] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*01"  
[3489] "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-58*02"   "IGHV1-69*04"   "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-2*02"   
[3497] "IGHV1-69*01"   "IGHV1-69*02"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*06"  
[3505] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"  
[3513] "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-46*01"  
[3521] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-3*01"   
[3529] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-8*01"   
[3537] "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*04"  
[3545] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[3553] "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"  
[3561] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"   
[3569] "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-58*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*01"  
[3577] "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*06"  
[3585] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"  
[3593] "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-24*01"  
[3601] "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*02"   
[3609] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-69*06"  
[3617] "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-69*01"  
[3625] "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-46*01"  
[3633] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"  
[3641] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-46*01"  
[3649] "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"   
[3657] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-3*01"   
[3665] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-18*01"  
[3673] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-3*01"   
[3681] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[3689] "IGHV1-2*02"    "IGHV1-58*01"   "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"  
[3697] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*04"   
[3705] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-18*01"  
[3713] "IGHV1-58*02"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*02"   
[3721] "IGHV1-2*04"    "IGHV1-58*02"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-69*06"   "IGHV1-18*01"  
[3729] "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-58*02"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*04"   
[3737] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-24*01"  
[3745] "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*06"  
[3753] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"   
[3761] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"  
[3769] "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"   
[3777] "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-46*01"  
[3785] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"  
[3793] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*01"  
[3801] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"  
[3809] "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-58*02"  
[3817] "IGHV1-69*01"   "IGHV1-69-2*01" "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-3*01"   
[3825] "IGHV1-2*04"    "IGHV1-24*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"  
[3833] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-8*01"   
[3841] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-24*01"  
[3849] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"   
[3857] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-18*01"  
[3865] "IGHV1-69-2*01" "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*06"  
[3873] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-18*01"  
[3881] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-2*02"   
[3889] "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-69*01"  
[3897] "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"  
[3905] "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-69*06"  
[3913] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-3*01"    "IGHV1-18*01"  
[3921] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-3*01"    "IGHV1-46*01"  
[3929] "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-24*01"  
[3937] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-69*06"  
[3945] "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[3953] "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-8*01"   
[3961] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*04"  
[3969] "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*06"  
[3977] "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-3*01"   
[3985] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-2*02"   
[3993] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-8*01"   
[4001] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-2*02"   
[4009] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*06"  
[4017] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"  
[4025] "IGHV1-69*04"   "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-46*01"  
[4033] "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[4041] "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*04"   
[4049] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-8*01"   
[4057] "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"  
[4065] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-58*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-8*01"   
[4073] "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-3*01"   
[4081] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*01"  
[4089] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"  
[4097] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-18*01"  
[4105] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*01"  
[4113] "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-2*04"   
[4121] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"  
[4129] "IGHV1-3*01"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*01"  
[4137] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*06"   "IGHV1-2*02"   
[4145] "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-24*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"  
[4153] "IGHV1-46*01"   "IGHV1-24*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"   
[4161] "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*01"  
[4169] "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-46*01"  
[4177] "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*01"  
[4185] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-24*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"   
[4193] "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-69*01"  
[4201] "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"  
[4209] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-46*01"  
[4217] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[4225] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*02"   
[4233] "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*01"  
[4241] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"  
[4249] "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-46*01"  
[4257] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-3*01"   
[4265] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"   
[4273] "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*04"  
[4281] "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-46*01"  
[4289] "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-58*02"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"   
[4297] "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"  
[4305] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"   
[4313] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"  
[4321] "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*02"   
[4329] "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"  
[4337] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"  
[4345] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69-2*01" "IGHV1-18*01"   "IGHV1-46*01"  
[4353] "IGHV1-2*02"    "IGHV1-58*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[4361] "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-18*01"  
[4369] "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"  
[4377] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*04"   
[4385] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-24*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[4393] "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[4401] "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-18*01"  
[4409] "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*02"   
[4417] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*01"  
[4425] "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-3*01"   
[4433] "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-69*06"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-8*01"   
[4441] "IGHV1-69*01"   "IGHV1-69*02"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-2*02"   
[4449] "IGHV1-58*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-2*04"   
[4457] "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*06"   "IGHV1-8*01"   
[4465] "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-69*06"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-2*02"   
[4473] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"  
[4481] "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"  
[4489] "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*01"  
[4497] "IGHV1-46*01"   "IGHV1-58*02"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-46*01"  
[4505] "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-46*01"  
[4513] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-18*01"  
[4521] "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-69*04"   "IGHV1-46*01"  
[4529] "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"  
[4537] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-3*01"    "IGHV1-46*01"   "IGHV1-69-2*01" "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-69*06"  
[4545] "IGHV1-18*01"   "IGHV1-69-2*01" "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*06"  
[4553] "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-18*01"  
[4561] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-8*01"   
[4569] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-46*01"   "IGHV1-69*01"  
[4577] "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-69*06"  
[4585] "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-2*04"   
[4593] "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-2*02"   
[4601] "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-58*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"  
[4609] "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-2*04"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-18*01"  
[4617] "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-8*01"    "IGHV1-69*01"  
[4625] "IGHV1-24*01"   "IGHV1-3*01"    "IGHV1-2*04"    "IGHV1-24*01"   "IGHV1-69*06"   "IGHV1-2*02"    "IGHV1-69*06"   "IGHV1-2*04"   
[4633] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-69*01"   "IGHV1-18*01"  
[4641] "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-3*01"    "IGHV1-2*02"    "IGHV1-18*01"  
[4649] "IGHV1-69*01"   "IGHV1-69*04"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-2*02"   
[4657] "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-69*04"   "IGHV1-69*06"   "IGHV1-18*01"  
[4665] "IGHV1-69*04"   "IGHV1-69-2*01" "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-2*02"    "IGHV1-3*01"    "IGHV1-69*06"   "IGHV1-18*01"  
[4673] "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-2*04"    "IGHV1-46*01"   "IGHV1-2*02"   
[4681] "IGHV1-69*04"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*02"   "IGHV1-24*01"   "IGHV1-2*04"    "IGHV1-18*01"  
[4689] "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-18*01"   "IGHV1-24*01"   "IGHV1-2*04"    "IGHV1-2*02"    "IGHV1-69*04"  
[4697] "IGHV1-2*02"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-3*01"    "IGHV1-18*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*06"  
[4705] "IGHV1-46*01"   "IGHV1-69*06"   "IGHV1-8*01"    "IGHV1-18*01"   "IGHV1-8*01"    "IGHV1-2*04"    "IGHV1-69*04"   "IGHV1-18*01"  
[4713] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-69*04"   "IGHV1-46*01"   "IGHV1-2*04"    "IGHV1-18*01"   "IGHV1-2*02"   
[4721] "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-2*02"    "IGHV1-2*04"    "IGHV1-69*01"   "IGHV1-8*01"    "IGHV1-69*01"   "IGHV1-18*01"  
[4729] "IGHV1-69*01"   "IGHV1-24*01"   "IGHV1-69*04"   "IGHV1-18*01"   "IGHV1-69*04"   "IGHV1-69*01"   "IGHV1-69*01"   "IGHV1-69*01"  
[4737] "IGHV1-18*01"   "IGHV1-46*01"   "IGHV1-2*02"    "IGHV1-46*01"   "IGHV1-69*01"   "IGHV1-46*01"   "IGHV1-18*01"   "IGHV1-2*02"   

```




